/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table 7: 	Estimaes of the impact of aging on robot
			installations by country-industry pairs
			
Notes: 		1. Sample excludes Pakistan and Macau, which have
			no industry-level data
			2. Table A21 follows same code, but focuses on 
			heterogeneity within manufacturing using UNIDO data
			to normalize robot purchases
			3. Stata cannot compute the F-stat for the models
			in columns 2 and 5 of Panel B. 
			
Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_heterogeneity_emp_base.tex
            /results/table_heterogeneity_iv_emp_base.tex
			/results/table_heterogeneity_emp_klems.tex
			/results/table_heterogeneity_iv_emp_klems.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

	**************************
	*******Housekeeping*******
	**************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

* determine sample of countries in Table 1 *
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg if country_name!= "japan" & country_name!="russian federation"
gen full_sample=e(sample)

* keep relevant covariates *
keep isocode full_sample ${aging_measure}* ${instruments} $industry_covariates dreg* ${normalization_robots}

* expand dataset *
expand 19
gen industry_ifr=""
bys isocode: replace industry_ifr="agriculture" if _n==1
bys isocode: replace industry_ifr="automotive" if _n==2
bys isocode: replace industry_ifr="construction" if _n==3
bys isocode: replace industry_ifr="education" if _n==4
bys isocode: replace industry_ifr="electronics" if _n==5
bys isocode: replace industry_ifr="food" if _n==6
bys isocode: replace industry_ifr="furniture" if _n==7
bys isocode: replace industry_ifr="glass" if _n==8
bys isocode: replace industry_ifr="man_other" if _n==9
bys isocode: replace industry_ifr="metal_basic" if _n==10
bys isocode: replace industry_ifr="metal_machinery" if _n==11
bys isocode: replace industry_ifr="metal_products" if _n==12
bys isocode: replace industry_ifr="mining" if _n==13
bys isocode: replace industry_ifr="nman_other" if _n==14
bys isocode: replace industry_ifr="paper" if _n==15
bys isocode: replace industry_ifr="plastic_chemicals" if _n==16
bys isocode: replace industry_ifr="textiles" if _n==17
bys isocode: replace industry_ifr="utilities" if _n==18
bys isocode: replace industry_ifr="vehicles_other" if _n==19
expand 23
bys isocode industry_ifr: gen year=_n+1992 

* robotics variables by industry * country * year *
merge 1:1 isocode industry_ifr year using "${project}/clean_data/country_industry_robot_flows.dta", assert(1 3) nogenerate

* klems and UNIDO variables by industry * country * year *
merge m:1 isocode industry_ifr using "${project}/clean_data/country_industry_klems.dta", assert(1 3) nogenerate
merge m:1 isocode industry_ifr using "${project}/clean_data/country_industry_unido.dta", assert(1 3) nogenerate

* merge industry characteristics *
merge m:1 industry_ifr using "${project}/clean_data/replaceability_ifr19.dta", assert(3) nogenerate
merge m:1 industry_ifr using "${project}/clean_data/uscensus_industry_1990", nogenerate
merge m:1 industry_ifr using "${project}/clean_data/uscensus_industry_2000", nogenerate
gen routine_bcg=0
replace routine_bcg=1 if industry_ifr=="automotive"
replace routine_bcg=1 if industry_ifr=="electronics"
replace routine_bcg=1 if industry_ifr=="metal_machinery"
replace routine_bcg=1 if industry_ifr=="plastic_chemicals"

* Panel structure *
encode isocode, gen(cty_code)
encode industry_ifr, gen(industry_code)
egen cell_code=group(isocode industry_ifr)
egen indyear_code=group(industry_ifr year)
xtset cell_code year
sort cell_code year

* normalizations: average industry employment or klems *
gen emp_base=${normalization_robots}/19
gen emp_klems=klems_employees_1995

*dependency
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

* baseline robot density * 
sort cell_code year
bysort cell_code: egen base_robots1993=total(stock_imputed*(year==1993))

* sample selection: Countries for which we observe some robot data and are in our baseline sample *
gen sample_all=(1-tag_noobs_flow)*tag_classified_flow*full_sample 

	************************
	*******Estimation*******
	************************ 
	
*****************************************************************************************************************************
**************Table 7, Panel A: OLS models with purchases normalized by average industrial employment ***********************
*****************************************************************************************************************************

*Interactions: evaluated at means *
gen young_intensity_raw=(1-share_55_emp_1990)/share_55_emp_1990
sum young_intensity_raw, d
gen young_intensity=young_intensity_raw-r(mean)

gen routine_intensity_rep=replaceable  
sum routine_intensity_rep, d
replace routine_intensity_rep=routine_intensity_rep-r(mean)

gen routine_intensity_bcg=routine_bcg
sum routine_intensity_bcg, d
replace routine_intensity_bcg=routine_intensity_bcg-r(mean)

* dependent variable *
gen flows_pc=investment_robots/emp_base

* baseline robot density *
bysort cell_code: gen indbase1993_stock_pc=base_robots1993/emp_base		

cap drop prone_robots
gen prone_robots=routine_intensity_rep
reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					change_dependency   ///
					if sample_all==1, r	cluster(cty_code) 		
estimates store e1

cap drop prone_robots
gen prone_robots=routine_intensity_rep
reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					change_dependency c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1, r	cluster(cty_code) 				
estimates store e2

* computations reported in the text *
sum young_intensity if isocode=="USA" & year==1993, d
display "Effects at 90th percentile of aging: " _b[change_dependency]+`r(p90)'*_b[c.change_dependency#c.young_intensity]
display "Effects at 10th percentile of aging: "  _b[change_dependency]+`r(p10)'*_b[c.change_dependency#c.young_intensity]
sum prone_robots if isocode=="USA" & year==1993, d
display "Effects at 90th percentile of replaceability: " _b[change_dependency]+`r(p90)'*_b[c.change_dependency#c.prone_robots]
display "Effects at 10th percentile of replaceability: "  _b[change_dependency]+`r(p10)'*_b[c.change_dependency#c.prone_robots]


reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					indbase1993* change_dependency c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1, r	cluster(cty_code)						
estimates store e3

reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					indbase1993* i.cty_code c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1, r	cluster(cty_code)				
estimates store e4

cap drop prone_robots
gen prone_robots=routine_intensity_bcg
reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					change_dependency c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1, r	cluster(cty_code)				
estimates store e5

reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					indbase1993* change_dependency c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1, r	cluster(cty_code)						
estimates store e6

reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					indbase1993* i.cty_code c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1, r	cluster(cty_code)					
estimates store e7

* export tables *
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_heterogeneity_emp_base.tex", style(tex) ///
varlabels(change_dependency "Aging between 1990 and 2025" ///
		  c.change_dependency#c.young_intensity "Aging $ \times $ reliance on middle-aged" ///
		  c.change_dependency#c.prone_robots    "Aging $ \times $ opportunities for automation"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust, fmt(%7.0f %7.0f %7.2f) labels("Observations" "Countries in sample" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) ///
order(change_dependency c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) 

*****************************************************************************************************************************
**************Table 7, Panel B: IV models with purchases normalized by average industrial employment  ***********************
*****************************************************************************************************************************

ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					(change_dependency=$instruments)   ///
					if sample_all==1, r	cluster(cty_code) partial(i.(year industry_code)##c.($industry_covariates ))	
estimates store e1

cap drop prone_robots
gen prone_robots=routine_intensity_rep
ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					(change_dependency c.change_dependency#c.(young_intensity prone_robots)=$instruments c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1, r	cluster(cty_code)  partial(c.($industry_covariates )##(ib2014.year i.industry_code))				
estimates store e2

*Note: manual computation of F-stat reported in the table*
reg change_dependency $instruments c.($industry_covariates )##(ib2014.year i.industry_code) if e(sample)==1, r cluster(cty_code)
test $instruments 


ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					indbase1993* (change_dependency c.change_dependency#c.(young_intensity prone_robots)=$instruments c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1, r	cluster(cty_code)	partial(c.($industry_covariates )##(ib2014.year i.industry_code) indbase1993* )				
estimates store e3

					
ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					indbase1993* i.cty_code (c.change_dependency#c.(young_intensity prone_robots)=c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1, r	cluster(cty_code)   partial(c.($industry_covariates )##(ib2014.year i.industry_code) i.cty_code indbase1993* )				
estimates store e4

cap drop prone_robots
gen prone_robots=routine_intensity_bcg
ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					(change_dependency c.change_dependency#c.(young_intensity prone_robots)=$instruments c.($instruments )#c.(young_intensity prone_robots))  ///
					if sample_all==1, r	cluster(cty_code)	partial(c.($industry_covariates )##(ib2014.year i.industry_code))				
estimates store e5

*Note: manual computation of F-stat reported in the table*
reg change_dependency $instruments c.($industry_covariates )##(ib2014.year i.industry_code) if e(sample)==1, r cluster(cty_code)
test $instruments 

ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					indbase1993* (change_dependency c.change_dependency#c.(young_intensity prone_robots)=$instruments c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1, r	cluster(cty_code)	partial(c.($industry_covariates )##(ib2014.year i.industry_code) indbase1993* ) 				
estimates store e6

ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					indbase1993* i.cty_code (c.change_dependency#c.(young_intensity prone_robots)=c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1, r	cluster(cty_code)   partial(c.($industry_covariates )##(ib2014.year i.industry_code) i.cty_code indbase1993* )				
estimates store e7

* export tables *
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_heterogeneity_iv_emp_base.tex", style(tex) ///
varlabels(change_dependency "Aging between 1990 and 2025" ///
		  c.change_dependency#c.young_intensity "Aging $ \times $ reliance on middle-aged" ///
		  c.change_dependency#c.prone_robots    "Aging $ \times $ opportunities for automation"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust  widstat jp, fmt(%7.0f %7.0f  %7.1f %7.2f) labels("Observations" "Countries in sample"  "First-stage $ F$ stat." "Overid p-value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) ///
order(change_dependency c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) 

drop flows_pc indbase1993* young_intensity* routine_intensity*  

*****************************************************************************************************************************
**************Table 7, Panel C: OLS models with purchases normalized by average industrial employment ***********************
*****************************************************************************************************************************

* weights *
bys isocode year: egen total_wt=total(emp_klems)
gen altwts=emp_klems/total_wt

*Interactions: evaluated at means *
gen young_intensity_raw=(1-share_55_emp_1990)/share_55_emp_1990
sum young_intensity_raw [w=altwts], d
gen young_intensity=young_intensity_raw-r(mean)

gen routine_intensity_rep=replaceable  
sum routine_intensity_rep [w=altwts], d
replace routine_intensity_rep=routine_intensity_rep-r(mean)

gen routine_intensity_bcg=routine_bcg
sum routine_intensity_bcg [w=altwts], d
replace routine_intensity_bcg=routine_intensity_bcg-r(mean)

* dependent variable *
gen flows_pc=investment_robots/emp_klems

* baseline robot density *
bysort cell_code: gen indbase1993_stock_pc=base_robots1993/emp_klems		

reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					change_dependency   ///
					if sample_all==1 [w=altwts], r	cluster(cty_code) 		
estimates store e1

cap drop prone_robots
gen prone_robots=routine_intensity_rep
reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					change_dependency c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1 [w=altwts], r	cluster(cty_code) 				
estimates store e2

reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					indbase1993* change_dependency c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1 [w=altwts], r	cluster(cty_code)						
estimates store e3

reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					indbase1993* i.cty_code c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1 [w=altwts], r	cluster(cty_code)				
estimates store e4

cap drop prone_robots
gen prone_robots=routine_intensity_bcg
reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					change_dependency c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1 [w=altwts], r	cluster(cty_code)				
estimates store e5

reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					indbase1993* change_dependency c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1 [w=altwts], r	cluster(cty_code)						
estimates store e6

reg flows_pc    	(ib2014.year i.industry_code)##c.($industry_covariates ) ///
					indbase1993* i.cty_code c.change_dependency#c.(young_intensity prone_robots)  ///
					if sample_all==1 [w=altwts], r	cluster(cty_code)					
estimates store e7

* export tables *
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_heterogeneity_emp_klems.tex", style(tex) ///
varlabels(change_dependency "Aging between 1990 and 2025" ///
		  c.change_dependency#c.young_intensity "Aging $ \times $ reliance on middle-aged" ///
		  c.change_dependency#c.prone_robots    "Aging $ \times $ opportunities for automation"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust, fmt(%7.0f %7.0f %7.2f) labels("Observations" "Countries in sample" "R-squared")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) ///
order(change_dependency c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) 

*****************************************************************************************************************************
**************Table 7, Panel D: IV models with purchases normalized by average industrial employment  ***********************
*****************************************************************************************************************************

ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					(change_dependency=$instruments)   ///
					if sample_all==1 [w=altwts], r	cluster(cty_code) partial(i.(year industry_code)##c.($industry_covariates ))	
estimates store e1

cap drop prone_robots
gen prone_robots=routine_intensity_rep
ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					(change_dependency c.change_dependency#c.(young_intensity prone_robots)=$instruments c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1 [w=altwts], r	cluster(cty_code)  partial(c.($industry_covariates )##(ib2014.year i.industry_code))				
estimates store e2

ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					indbase1993* (change_dependency c.change_dependency#c.(young_intensity prone_robots)=$instruments c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1 [w=altwts], r	cluster(cty_code)	partial(c.($industry_covariates )##(ib2014.year i.industry_code) indbase1993* )				
estimates store e3
					
ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					indbase1993* i.cty_code (c.change_dependency#c.(young_intensity prone_robots)=c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1 [w=altwts], r	cluster(cty_code)   partial(c.($industry_covariates )##(ib2014.year i.industry_code) i.cty_code indbase1993* )				
estimates store e4

cap drop prone_robots
gen prone_robots=routine_intensity_bcg
ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					(change_dependency c.change_dependency#c.(young_intensity prone_robots)=$instruments c.($instruments )#c.(young_intensity prone_robots))  ///
					if sample_all==1 [w=altwts], r	cluster(cty_code)	partial(c.($industry_covariates )##(ib2014.year i.industry_code))				
estimates store e5

ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					indbase1993* (change_dependency c.change_dependency#c.(young_intensity prone_robots)=$instruments c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1 [w=altwts], r	cluster(cty_code)	partial(c.($industry_covariates )##(ib2014.year i.industry_code) indbase1993* ) 				
estimates store e6

ivreg2 flows_pc    	c.($industry_covariates )##(ib2014.year i.industry_code) ///
					indbase1993* i.cty_code (c.change_dependency#c.(young_intensity prone_robots)=c.($instruments )#c.(young_intensity prone_robots))   ///
					if sample_all==1 [w=altwts], r	cluster(cty_code)   partial(c.($industry_covariates )##(ib2014.year i.industry_code) i.cty_code indbase1993* )				
estimates store e7

* export tables *
estout e1 e2 e3 e4 e5 e6 e7 using "$project/results/table_heterogeneity_iv_emp_klems.tex", style(tex) ///
varlabels(change_dependency "Aging between 1990 and 2025" ///
		  c.change_dependency#c.young_intensity "Aging $ \times $ reliance on middle-aged" ///
		  c.change_dependency#c.prone_robots    "Aging $ \times $ opportunities for automation"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N N_clust  widstat jp, fmt(%7.0f %7.0f  %7.1f %7.2f) labels("Observations" "Countries in sample"  "First-stage $ F$ stat." "Overid p-value")) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) ///
order(change_dependency c.change_dependency#c.young_intensity c.change_dependency#c.prone_robots) 

