/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A18: 	Robustness for IV estimates of aging on the location
			of robot integrators in the US
			
Notes: 		1. uses data available in the replication kit of
            "Robots and Jobs: Evidence from US labor markets"
	        czones_integrators
	        czones_covariates_1990
	        czones_exposure_longdif
			2. the single IV within the US is the decline in birthrates 
			between 1950 and 1980. This matches the period of 
			fast birthrate decline for the country as a whole

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_appendix_integrators_outliers.tex
			/results/table_appendix_integrators_weight.tex
			/results/table_appendix_integrators_log_num.tex
			/results/table_appendix_integrators_log_emp.tex
			/results/table_appendix_integrators_ivprobit.tex
			/results/table_appendix_integrators_ivprobit_marginal.tex

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

* programs for removing outliers *
cap program drop reg_outliers
program define reg_outliers, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	tempvar residual
	tempvar cons_sample
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r cluster(state)
	predict `residual' if e(sample)==1, resid
	quietly: sum `residual'
	gen `cons_sample'=(`residual'>-1.96*r(sd) & `residual'<1.96*r(sd)) if e(sample)==1
	reg `y_vars' `x_var' `controls'  `wt'  if `cons_sample'==1, r cluster(state)
end

cap program drop ivreg_outliers
program define ivreg_outliers, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	tempvar residual
	tempvar cons_sample
	
	quietly: ivreg2 `y_vars' (`x_var'=single_iv) `controls'  `wt'  `if', r  cluster(state)
	predict `residual' if e(sample)==1, resid
	quietly: sum `residual'
	gen `cons_sample'=(`residual'>-1.96*r(sd) & `residual'<1.96*r(sd)) if e(sample)==1
	ivreg2 `y_vars' (`x_var'=single_iv) `controls'  `wt'  if `cons_sample'==1, r  cluster(state)
end

	**************************
	*******Housekeeping*******
	**************************
	

* data from R&J replication kit *
use "${project}/clean_data/czones_integrators.dta", clear
merge 1:1 czone using "${project}/clean_data/czones_exposure_longdif.dta", assert(3) nogenerate
merge 1:1 czone using "${project}/clean_data/czones_covariates_1990.dta", assert(3) nogenerate

* additional controls and measures of aging *
merge 1:1 czone using "${project}/clean_data/czones_demographics", assert(3) nogenerate

* define alternative instrument *
gen    single_iv=ln(brate1950)-ln(brate1980)

* control variables *
gen nhgis_ln_gdp_1990=ln(nhgis_percapita_income_1990)
gen log_pop_1990=ln(population_1990)

*measures of aging: change in dependency ratio between 1990 and 2015 *
gen change_dep=${aging_measure}2015-${aging_measure}1990
gen base_dep=${aging_measure}1990

*groups of covariates and measure of exposure*
global demographics_cz     nhgis_male_share_1990 nhgis_urban_share_1990 base_dep nhgis_ln_gdp_1990 log_pop_1990 nhgis_edu_*1990 nhgis_race_*1990 
global other_shocks_cz     chinashock_iv_90_07 expo_share_occ_routine_1990 
global industry_shares_cz  nhgis_empsh_* 
global regional_dummies_cz i.region


	************************
	*******Estimation*******
	************************ 
	
**********************************************************************************************
************************Table A18, Panel A: Removing outliers ********************************
**********************************************************************************************

* dummy for location of integrators *
gen loc_integrator=dum_int

ivreg_outliers  loc_integrator  change_dep, controls($regional_dummies_cz )
estimates store e1

*Basic demographic controls (same set used in cross country analysis)*
ivreg_outliers  loc_integrator  change_dep, controls($demographics_cz $regional_dummies_cz )
estimates store e2

*Control for potential for automation and industry composition*
ivreg_outliers  loc_integrator  change_dep, controls(expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $regional_dummies_cz )
estimates store e3

*Additional covariates*
ivreg_outliers  loc_integrator  change_dep, controls(expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz )
estimates store e4

*Controlling for high exposure regions*
ivreg_outliers  loc_integrator  change_dep if tag_exposure==1, controls(expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz )
estimates store e5

*Export tables*
estout e1 e2 e3 e4 e5 using  "$project/results/table_appendix_integrators_outliers.tex", style(tex) ///
varlabels(expof_euro5_qo93_07     "Exposure to robots" ///
		  change_dep     "Aging between 1990 and 2015" ///
		  ln_gdp_1990 "log of income per capita in 1990"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat, fmt(%7.0f %7.1f) labels("Observations" "First-stage $ F$  stat." )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dep  ) ///
order(change_dep )

**********************************************************************************************
************************Table A18, Panel B: Weighting by population size    ******************
**********************************************************************************************
ivreg2  loc_integrator (change_dep=single_iv) $regional_dummies_cz [w=population_1990], r cluster(state)
estimates store e1

*Basic demographic controls (same set used in cross country analysis)*
ivreg2  loc_integrator (change_dep=single_iv) $demographics_cz $regional_dummies_cz [w=population_1990], r cluster(state)
estimates store e2

*Control for potential for automation and industry composition*
ivreg2  loc_integrator (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $regional_dummies_cz [w=population_1990], r cluster(state)
estimates store e3

*Additional covariates*
ivreg2  loc_integrator (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz [w=population_1990], r cluster(state)
estimates store e4

*Controlling for high exposure regions*
ivreg2  loc_integrator (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz [w=population_1990] if tag_exposure==1, r cluster(state)
estimates store e5

*Export tables*
estout e1 e2 e3 e4 e5  using  "$project/results/table_appendix_integrators_weight.tex", style(tex) ///
varlabels(expof_euro5_qo93_07     "Exposure to robots" ///
          change_dep     "Aging between 1990 and 2015" ///
		  ln_gdp_1990 "log of income per capita in 1990"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat, fmt(%7.0f %7.1f) labels("Observations" "First-stage $ F$  stat." )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dep  ) ///
order(change_dep )

**********************************************************************************************
************************Table A18, Panel C: Log of one plus integrators **********************
**********************************************************************************************
ivreg2  log_num_int (change_dep=single_iv) $regional_dummies_cz, r cluster(state)
estimates store e1

*Basic demographic controls (same set used in cross country analysis)*
ivreg2  log_num_int (change_dep=single_iv) $demographics_cz $regional_dummies_cz, r cluster(state)
estimates store e2

*Control for potential for automation and industry composition*
ivreg2  log_num_int (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $regional_dummies_cz, r cluster(state)
estimates store e3

*Additional covariates*
ivreg2  log_num_int (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz, r cluster(state)
estimates store e4

*controlling for high exposure areas*
ivreg2  log_num_int (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz if tag_exposure==1, r cluster(state)
estimates store e5

*Export tables*
estout e1 e2 e3 e4 e5  using  "$project/results/table_appendix_integrators_log_num.tex", style(tex) ///
varlabels(expof_euro5_qo93_07     "Exposure to robots" ///
          change_dep     "Aging between 1990 and 2015" ///
		  ln_gdp_1990 "log of income per capita in 1990"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat, fmt(%7.0f %7.1f) labels("Observations" "First-stage $ F$  stat." )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dep  ) ///
order(change_dep )

**********************************************************************************************
************************Table A18, Panel D: Log of one plus integrators employment ***********
**********************************************************************************************
ivreg2  log_emp_int (change_dep=single_iv) $regional_dummies_cz, r cluster(state)
estimates store e1

*Basic demographic controls (same set used in cross country analysis)*
ivreg2  log_emp_int (change_dep=single_iv) $demographics_cz $regional_dummies_cz, r cluster(state)
estimates store e2

*Control for potential for automation and industry composition*
ivreg2  log_emp_int (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $regional_dummies_cz, r cluster(state)
estimates store e3

*Additional covariates*
ivreg2  log_emp_int (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz, r cluster(state)
estimates store e4

*controlling for high exposure areas*
ivreg2  log_emp_int (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz if tag_exposure==1, r cluster(state)
estimates store e5

*Export tables*
estout e1 e2 e3 e4 e5  using  "$project/results/table_appendix_integrators_log_emp.tex", style(tex) ///
varlabels(expof_euro5_qo93_07     "Exposure to robots" ///
          change_dep     "Aging between 1990 and 2015" ///
		  ln_gdp_1990 "log of income per capita in 1990"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N widstat, fmt(%7.0f %7.1f) labels("Observations" "First-stage $ F$  stat." )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dep  ) ///
order(change_dep )


**************************************************************************************************************
************************Table Referee, Panel E: Probit********************************************************
************************Note: we use version 13.1 of margins command due to weird behavior of new one*********
**************************************************************************************************************

ivprobit  loc_integrator (change_dep=single_iv) $regional_dummies_cz, vce(cluster state)
estimates store e1
version 13.1: margins , dydx(change_dep) predict(pr) post
estimates store e1b

*Basic demographic controls (same set used in cross country analysis)*
ivprobit  loc_integrator (change_dep=single_iv) $demographics_cz $regional_dummies_cz, vce(cluster state)
estimates store e2
version 13.1: margins , dydx(change_dep) predict(pr) post
estimates store e2b

*Control for potential for automation and industry composition*
ivprobit  loc_integrator (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $regional_dummies_cz, vce(cluster state)
estimates store e3
version 13.1: margins , dydx(change_dep) predict(pr) post
estimates store e3b

*Additional covariates*
ivprobit  loc_integrator (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz, vce(cluster state)
estimates store e4
version 13.1: margins , dydx(change_dep) predict(pr) post
estimates store e4b

*Remove areas with high exposure*
ivprobit  loc_integrator (change_dep=single_iv) expof_euro5_qo93_07 $demographics_cz $industry_shares_cz $other_shocks_cz $regional_dummies_cz if tag_exposure==1, vce(cluster state)
estimates store e5
version 13.1: margins , dydx(change_dep) predict(pr) post
estimates store e5b

*Export tables*
estout e1 e2 e3 e4 e5 using  "$project/results/table_appendix_integrators_ivprobit.tex", style(tex) ///
varlabels(expof_euro5_qo93_07     "Exposure to robots" ///
		  change_dep     "Aging between 1990 and 2015" ///
		  ln_gdp_1990 "log of income per capita in 1990"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(, fmt(%7.0f) labels("Observations" )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dep  ) ///
order(change_dep )

estout e1b e2b e3b e4b e5b using  "$project/results/table_appendix_integrators_ivprobit_marginal.tex", style(tex) ///
varlabels(expof_euro5_qo93_07     "Exposure to robots" ///
		  change_dep     "Average marginal effect" ///
		  ln_gdp_1990 "log of income per capita in 1990"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N, fmt(%7.0f) labels("Observations" )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dep  ) ///
order(change_dep )






