/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
Table A4: 	Estimates of the impact of aging on the adoption of
			industrial robots controlling for the
			influence of outliers

Notes: 		

Revision:   Pascual Restrepo 7/16/2020
			Eric Donald 7/31/2020
			
Output: 	/results/table_outliers_remove.tex			
			/results/table_outliers_korea.tex
			/results/table_outliers_korea_weighted.tex
			/results/table_outliers_weighted.tex
			/results/table_outliers_qreg.tex
			/results/table_outliers_mreg
			/results/table_outliers_mmreg

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

***Program to drop outliers***
cap program drop reg_outliers
program define reg_outliers, eclass 

syntax varlist(min=2 numeric) [if] [in] [aweight fweight], ///
		[CONTROLs(varlist numeric ts fv)]
		
		* Create convenient weight local
	    if ("`weight'"!="") local wt [`weight'`exp']
	
	* Parse varlist into y-vars and x-var
	local x_var=word("`varlist'",-1)
	local y_vars=regexr("`varlist'"," `x_var'$","")
	tempvar residual
	tempvar cons_sample
	
	quietly: reg `y_vars' `x_var' `controls'  `wt'  `if', r
	predict `residual' if e(sample)==1, resid
	quietly: sum `residual'
	gen `cons_sample'=(`residual'>-1.96*r(sd) & `residual'<1.96*r(sd)) if e(sample)==1
	reg `y_vars' `x_var' `controls'  `wt'  if `cons_sample'==1, r
end

	**************************
	*******Housekeeping*******
	**************************

* covariates *
use "$project/clean_data/country_covariates.dta", clear

* robotics variables *
merge 1:1 isocode using "${project}/clean_data/country_robot_stocks.dta", assert(1 3) nogenerate

* demographics variables *
merge 1:1 isocode using "${project}/clean_data/country_demographics.dta", assert(1 3) nogenerate

*regions*
encode new_region, gen(dreg) /*previous version used region. not new_region*/

*robot variables*
gen base1993_stock_pc=stock_robots_1993/${normalization_robots}
gen change_robots=(stock_robots_2014-stock_robots_1993)/(2014-1993)/${normalization_robots}

*aging variables, controls and instruments *
gen change_dependency=(${aging_measure}2025-${aging_measure}1990)

*sample selection*
keep if country_name!= "japan" & country_name!="russian federation" 
quietly: reg change_robots $country_covariates ln_manuf_va  base1993_stock_pc i.dreg
gen full_sample=e(sample)



*****************************************************************************************
************************Table A4, Panel D: OLS models, remove outliers ******************
*****************************************************************************************
reg_outliers change_robots 	change_dependency if full_sample==1 , controls( i.dreg $country_covariates) 
estimates store e1

reg_outliers change_robots 	change_dependency if full_sample==1 , controls(ln_manuf_va  base1993_stock_pc i.dreg $country_covariates) 
estimates store e2

reg_outliers change_robots 	change_dependency if new_region=="OECD" , controls( i.dreg $country_covariates) 
estimates store e3

reg_outliers change_robots 	change_dependency if new_region=="OECD" , controls(ln_manuf_va  base1993_stock_pc i.dreg $country_covariates) 
estimates store e4

*Export tables*
estout e1 e2 e3 e4 using  "$project/results/table_outliers_remove.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N , fmt(%7.0f) labels("Observations" )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )


*****************************************************************************************
************************Table A4, Panel A: OLS models, remove Korea *********************
*****************************************************************************************
reg change_robots 	change_dependency i.dreg $country_covariates if full_sample & country_name!="south korea", r
estimates store e1

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample & country_name!="south korea", r
estimates store e2

reg change_robots 	change_dependency $country_covariates if new_region=="OECD" & country_name!="south korea", r
estimates store e3

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc  $country_covariates if new_region=="OECD" & country_name!="south korea", r
estimates store e4

*Export tables*
estout e1 e2 e3 e4 using  "$project/results/table_outliers_korea.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N , fmt(%7.0f) labels("Observations" )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )

*****************************************************************************************
******Table A4, Panel B: OLS models, remove Korea, weight by manufacturing value added **
*****************************************************************************************
reg change_robots 	change_dependency i.dreg $country_covariates if full_sample & country_name!="south korea" $robot_weight, r
estimates store e1

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample & country_name!="south korea"  $robot_weight, r
estimates store e2

reg change_robots 	change_dependency $country_covariates if new_region=="OECD" & country_name!="south korea"  $robot_weight, r
estimates store e3

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc  $country_covariates if new_region=="OECD" & country_name!="south korea"  $robot_weight, r
estimates store e4

*Export tables*
estout e1 e2 e3 e4 using  "$project/results/table_outliers_korea_weighted.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N , fmt(%7.0f) labels("Observations" )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )

*****************************************************************************************
******************Table A4, Panel C: OLS models, weighted by industrial employment ******
*****************************************************************************************
reg change_robots 	change_dependency i.dreg $country_covariates if full_sample [w=$normalization_robots], r
estimates store e1

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc i.dreg $country_covariates if full_sample [w=$normalization_robots], r
estimates store e2

reg change_robots 	change_dependency $country_covariates if new_region=="OECD" [w=$normalization_robots], r
estimates store e3

reg change_robots 	change_dependency ln_manuf_va  base1993_stock_pc $country_covariates if new_region=="OECD" [w=$normalization_robots], r
estimates store e4

*Export tables*
estout e1 e2 e3 e4 using  "$project/results/table_outliers_weighted.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N , fmt(%7.0f) labels("Observations" )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )

*****************************************************************************************
************************Table A4, Panel E: Quantile regression **************************
*****************************************************************************************
qreg change_robots 	change_dependency i.dreg $country_covariates if full_sample, vce(robust)
estimates store e1

qreg change_robots 	change_dependency i.dreg $country_covariates ln_manuf_va  base1993_stock if full_sample, vce(robust)
estimates store e2

qreg change_robots 	change_dependency i.dreg $country_covariates if new_region=="OECD", vce(robust)
estimates store e3

qreg change_robots 	change_dependency i.dreg $country_covariates ln_manuf_va  base1993_stock if new_region=="OECD", vce(robust)
estimates store e4

*Export tables*
estout e1 e2 e3 e4 using  "$project/results/table_outliers_qreg.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N , fmt(%7.0f) labels("Observations" )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )

*****************************************************************************************
************************Table A4, Panel F: Huber M-regression ***************************
*****************************************************************************************
xi: mregress change_robots 	change_dependency i.dreg $country_covariates if full_sample
estimates store e1

xi: mregress change_robots 	change_dependency i.dreg $country_covariates ln_manuf_va  base1993_stock if full_sample
estimates store e2

xi: mregress change_robots 	change_dependency $country_covariates if new_region=="OECD"
estimates store e3

xi: mregress change_robots 	change_dependency $country_covariates ln_manuf_va  base1993_stock if new_region=="OECD"
estimates store e4

*Export tables*
estout e1 e2 e3 e4 using  "$project/results/table_outliers_mreg.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N , fmt(%7.0f) labels("Observations" )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )

*****************************************************************************************
************************Table A4, Panel G: Yohsi MM-regression **************************
*****************************************************************************************
xi: robreg mm change_robots 	change_dependency i.dreg $country_covariates if full_sample
estimates store e1

xi: robreg mm change_robots 	change_dependency i.dreg $country_covariates ln_manuf_va  base1993_stock if full_sample
estimates store e2

robreg mm change_robots 	change_dependency $country_covariates if new_region=="OECD"
estimates store e3

robreg mm change_robots 	change_dependency $country_covariates ln_manuf_va  base1993_stock if new_region=="OECD"
estimates store e4

*Export tables*
estout e1 e2 e3 e4 using  "$project/results/table_outliers_mmreg.tex", style(tex) ///
varlabels(change_dependency     "Aging between 1990 and 2025" ///
		  log_pwt_output_capita1993 "log of GDP per capita in 1993"  ) ///
		  cells(b(nostar fmt(%9.3f)) se(par)) stats(N , fmt(%7.0f) labels("Observations" )) nolabel replace mlabels(none) collabels(none) starlevels(\$^{*}\$ .1 \$^{**}\$ .05 \$^{***}\$ .01) ///
keep(change_dependency  ) ///
order(change_dependency )

